@@ -8,20 +8,13 @@ Created on Mon Sep 21 11:29:27 2020
 import pyvisa
 from time import sleep
 
-from serial.tools import list_ports
 
 
 class MaiTai:
 
-    def __init__(self,serial_number):
+    def __init__(self,port):
         rm = pyvisa.ResourceManager()
-        ports = list_ports.comports()
-        current_port = "None"
-        for port in ports:
-            if port.serial_number == serial_number:
-                current_port = port.name
-        if current_port == "None":
-            print("PORT NOT FOUND")
+        current_port = port.name
         self.MaiTai = rm.open_resource(f'ASRL/{current_port}::INSTR')
         self.MaiTai.baud_rate = 115200
 
@@ -62,7 +55,3 @@ class MaiTai:
 
 
 
-
-if __name__=='__main__':
-    MaiTai = MaiTai()
-
