@@ -6,10 +6,10 @@ Created on Mon Sep 21 12:38:26 2020
 @author: briansquires
 """
 
-from StellarNet import StellarNet
-import Photodiode
+from .StellarNet import StellarNet
+from . import Photodiode
 #from MaiTai import MaiTai
-from instruments import CRotator
+from . import CRotator
 import matplotlib.pyplot as plt
 import time
 import numpy as np
