@@ -1,6 +1,6 @@
-from neogiinstruments.esp300 import ESP300
+from .esp300 import ESP300
 from time import sleep
-from Photodiode import Photodiode
+from .Photodiode import Photodiode
 import matplotlib.pyplot as plt
 if __name__ == "__main__":
     ESP300 = ESP300()
